Documentation
¶
Overview ¶
Package app implements a Server object for running the descheduler.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewDeschedulerCommand ¶
NewDeschedulerCommand creates a *cobra.Command object with default parameters
func NewVersionCommand ¶
func Run ¶
func Run(rs *options.DeschedulerServer) error
Types ¶
type Info ¶
type Info struct {
Major string `json:"major"`
Minor string `json:"minor"`
GitCommit string `json:"gitCommit"`
GitVersion string `json:"gitVersion"`
BuildDate string `json:"buildDate"`
GoVersion string `json:"goVersion"`
Compiler string `json:"compiler"`
Platform string `json:"platform"`
}
Info holds the information related to descheduler app version.
Click to show internal directories.
Click to hide internal directories.